==> Paws-0.30.tar.gz: Paws-0.30/lib/Paws/AppStream/Stack.pm <==
package Paws::AppStream::Stack;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str');
  has CreatedTime => (is => 'ro', isa => 'Str');
  has Description => (is => 'ro', isa => 'Str');
  has DisplayName => (is => 'ro', isa => 'Str');
  has Name => (is => 'ro', isa => 'Str', required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::AppStream::Stack

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::AppStream::Stack object:

  $service_obj->Method(Att1 => { Arn => $value, ..., Name => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::AppStream::Stack object:

  $result = $service_obj->Method(...);
  $result->Att1->Arn

=head1 DESCRIPTION

Details about a stack.

=head1 ATTRIBUTES


=head2 Arn => Str

  The ARN of the stack.


=head2 CreatedTime => Str

  The timestamp when the stack was created.


=head2 Description => Str

  A meaningful description for the stack.


=head2 DisplayName => Str

  A display name for the stack.


=head2 B<REQUIRED> Name => Str

  The unique identifier of the stack.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::AppStream>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/AppStream/Stack.pm <==
package Paws::AppStream::Stack;
  use Moose;
  has Arn => (is => 'ro', isa => 'Str');
  has CreatedTime => (is => 'ro', isa => 'Str');
  has Description => (is => 'ro', isa => 'Str');
  has DisplayName => (is => 'ro', isa => 'Str');
  has Name => (is => 'ro', isa => 'Str', required => 1);
  has StackErrors => (is => 'ro', isa => 'ArrayRef[Paws::AppStream::StackError]');
  has StorageConnectors => (is => 'ro', isa => 'ArrayRef[Paws::AppStream::StorageConnector]');
1;

### main pod documentation begin ###

=head1 NAME

Paws::AppStream::Stack

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::AppStream::Stack object:

  $service_obj->Method(Att1 => { Arn => $value, ..., StorageConnectors => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::AppStream::Stack object:

  $result = $service_obj->Method(...);
  $result->Att1->Arn

=head1 DESCRIPTION

Details about a stack.

=head1 ATTRIBUTES


=head2 Arn => Str

  The ARN of the stack.


=head2 CreatedTime => Str

  The timestamp when the stack was created.


=head2 Description => Str

  A meaningful description for the stack.


=head2 DisplayName => Str

  A display name for the stack.


=head2 B<REQUIRED> Name => Str

  The unique identifier of the stack.


=head2 StackErrors => ArrayRef[L<Paws::AppStream::StackError>]

  The list of errors associated with the stack.


=head2 StorageConnectors => ArrayRef[L<Paws::AppStream::StorageConnector>]

  The storage connectors to be enabled for the stack.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::AppStream>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
